@@ -51,6 +51,13 @@ def addoptions(parser):
     group.addoption("--debug", action="store_true",
             help="run wsgi application with debug logging")
 
+def try_argcomplete(parser):
+    try:
+        import argcomplete
+    except ImportError:
+        pass
+    else:
+        argcomplete.autocomplete(parser)
 
 def parseoptions(argv, addoptions=addoptions):
     if argv is None:
@@ -62,6 +69,7 @@ def parseoptions(argv, addoptions=addoptions):
                     "The server automatically refreshes the cache of all "
                     "indexes which have changed on the pypi.python.org side.")
     addoptions(parser)
+    try_argcomplete(parser)
     args = parser.parse_args(argv[1:])
     config = Config(args)
     return config
