@@ -61,6 +61,10 @@ def test_simple_project(pypiurls, httpget, testapp):
     assert len(links) == 1
     assert links[0].get("href").endswith(path)
 
+def test_simple_url_longer_triggers_404(testapp):
+    assert testapp.get("/root/pypi/+simple/pytest/1.0/").status_code == 404
+    assert testapp.get("/root/pypi/+simple/pytest/1.0").status_code == 404
+
 def test_simple_project_pypi_egg(pypiurls, httpget, testapp):
     httpget.setextsimple("py",
         """<a href="http://bb.org/download/py.zip#egg=py-dev" />""")
